@@ -1,38 +1,51 @@
+"""Rewriting functionality for RDFlib graphs."""
+
 import logging
-from typing import List
+from typing import Any, Dict, List, Optional
 
+from linkml_runtime.utils.metamodelcore import URIorCURIE
 from rdflib import Graph, URIRef
-from rdflib.plugins.memory import Any
 
-from sssom import Mapping
-from sssom.parsers import to_mapping_set_document
-from sssom.util import MappingSetDataFrame
+# from .sssom_datamodel import EntityReference, Mapping
+from sssom_schema import EntityReference, Mapping
+
+from .parsers import to_mapping_set_document
+from .util import MappingSetDataFrame
+
+__all__ = [
+    "rewire_graph",
+]
 
 
 def rewire_graph(
     g: Graph,
     mset: MappingSetDataFrame,
-    subject_to_object=True,
-    precedence: List[str] = None,
-) -> str:
-    """
-    rewires an RDF Graph replacing using equivalence mappings
-    """
-    pm = mset.prefixmap
+    subject_to_object: bool = True,
+    precedence: Optional[List[str]] = None,
+) -> int:
+    """Rewire an RDF Graph replacing using equivalence mappings."""
+    pm = mset.prefix_map
     mdoc = to_mapping_set_document(mset)
-    rewire_map = {}
+    rewire_map: Dict[URIorCURIE, URIorCURIE] = {}
 
-    def expand_curie(curie: str):
+    def expand_curie(curie: str) -> URIRef:
         pfx, local = curie.split(":")
         return URIRef(f"{pm[pfx]}{local}")
 
+    if mdoc.mapping_set.mappings is None:
+        raise TypeError
     for m in mdoc.mapping_set.mappings:
-        m: Mapping
-        if m.predicate_id == "owl:equivalentClass":
+        if not isinstance(m, Mapping):
+            continue
+        if m.predicate_id in {"owl:equivalentClass", "owl:equivalentProperty"}:
             if subject_to_object:
                 src, tgt = m.subject_id, m.object_id
             else:
                 src, tgt = m.object_id, m.subject_id
+            if not isinstance(src, EntityReference) or not isinstance(
+                tgt, EntityReference
+            ):
+                raise TypeError
             if src in rewire_map:
                 curr_tgt = rewire_map[src]
                 logging.info(f"Ambiguous: {src} -> {tgt} vs {curr_tgt}")
@@ -49,12 +62,15 @@ def rewire_graph(
                     raise ValueError(f"Ambiguous: {src} -> {tgt} vs {curr_tgt}")
             else:
                 rewire_map[src] = tgt
-    rewire_map = {expand_curie(k): expand_curie(v) for k, v in rewire_map.items()}
+
+    uri_ref_rewire_map: Dict[URIRef, URIRef] = {
+        expand_curie(k): expand_curie(v) for k, v in rewire_map.items()
+    }
 
     def rewire_node(n: Any):
         if isinstance(n, URIRef):
-            if n in rewire_map:
-                return rewire_map[n]
+            if n in uri_ref_rewire_map:
+                return uri_ref_rewire_map[n]
             else:
                 return n
         else:
